@@ -43,7 +43,7 @@ class Storage(driver.Base):
     def get_json(self, path):
         logger.info("get_json path:%s" % path)
         try:
-            return json.loads(self.get_unicode("/tmp/registry/"+path))
+            return json.loads(self.get_unicode(path))
         except Exception as e:
             logger.error("get_json error:%s" % e)
             return []
@@ -78,7 +78,7 @@ class Storage(driver.Base):
         path1 = self._init_path(path)
         try:
             object_instance = self._jss.bucket(self._bucket).object(path1)
-            object_instance.upload_flow(None, None, content)
+            object_instance.upload_flow(headers=None, data=content)
         except Exception as e:
             logger.error("put_content error:%s" % e)
             raise e
